tinySAeasyConnector - Python Библиотека для TinySA Ultra
==========================================================


<p align="center">
<img  src="http://corvax.tech/tinySA.jpg"  width="450" alt="tinySA"/>
</p>

# О библитотеке

Библиотека создана для облегчения работы с TinySA при
помощи Python.

## WIKI

* [WIKI](https://gitflic.ru/project/corvax/tinysaeasyconnector/wiki)

## Примечание

TinySA является торговой маркой, принадлежащей соответствующему владельцу. Несанкционированное использование имени tinySA запрещено.


### Создатели

* [@corvax](https://gitflic.ru/user/corvax)